==> nocc-1.8.1.tbz: www/nocc/lang/fa.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fa.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Persian (فارسی)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$lang_locale = 'fa.UTF-8';
$lang_dir = 'rtl';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'شناسه کاربر خالى است';
$err_passwd_empty = 'رمز خالى است';
$alt_delete = 'پاک کردن پيغامهاى انتخاب شده';
$alt_delete_one = 'پاک کردن پيغام';
$alt_new_msg = 'پيغامهاى جديد';
$alt_reply = 'جواب به نويسنده';
$alt_reply_all = 'جواب به همه';
$alt_forward = 'فرستادن پيغام';
$title_next_page = 'پيغام بعدى';
$title_prev_page = 'پيغام قبلى';
$html_welcome = 'خوش آمديد به %1$s';
$html_login = 'شناسه کاربر';
$html_passwd = 'رمز';
$html_submit = 'ورود';
$html_help = 'کمک';
$html_server = 'سرور';
$html_wrong = 'شناسه کاربر يا رمز اشتباه است';
$html_retry = 'سعى دوباره';
$html_msgperpage_label = 'تعداد پيغامها در صفحه';
$html_preferences = 'تنظيمات';
$html_full_name_label = 'اسم کامل';
$html_email_address_label = 'آدرس نامه الکترونيکى';
$html_ccself = 'نسخه Cc براى خود';
$html_hide_addresses = 'آدرسها به صورت پنهانى';
$html_outlook_quoting = 'نقل قول شبيه Outlook';
$html_reply_to = 'پاسخ به';
$html_use_signature = 'استفاده از امضا';
$html_signature = 'امضا';
$html_prefs_updated = 'تنطيمات بروز شد';
$html_folders_create_failed = 'شاخه نمىتواند ايجاد شود';
$html_folders_rename_failed = 'شاخه نمىتواند تغيير نام يابد';
$html_folders_updated = 'شاخه ها بروز شدند';
$html_folder_rename = 'تغيير نام';
$html_folder_create = 'ساختن شاخه جديد صدا شد';
$html_folder_to = 'ﺐﻫ';
$html_new_msg_in = 'پيغامهاى جديد در';
$html_or = 'يا';
$html_move = 'تغيير مکان';
$html_copy = 'کپى';
$html_messages_to = 'پيغامهاى انتخاب شده به';
$html_gotopage = 'برو به صفحه';
$html_gotofolder = 'برو به شاخه';
$html_other_folders = 'ليست شاخه ها';
$html_page = 'صفحه';
$html_view_header = 'سرآيند را نشان بده';
$html_remove_header = 'سرآيند را پنهان کن';
$html_new_msg = 'نوشتن نامه';
$html_reply = 'پاسخ دادن';
$html_reply_all = 'پاسخ دادن به همه';
$html_forward = 'فرستادن';
$html_delete = 'پاک کردن';
$html_new = 'جديد';
$html_mark = 'پاک کردن';
$html_att_label = 'ضميمه';
$html_atts_label = 'ضميمه ها';
$html_att_unknown = '[ناشناخته]';
$html_attach = 'ضميمه کن';
$html_attach_forget = 'شما بايد فايل خود را قبل از فرستادن ضميمه کنيد';
$html_attach_delete = 'ضميمه هاى انتخاب شده را پاک کن';
$html_sort_by = 'ترتيب بندى با';
$html_from = 'از';
$html_subject = 'عنوان';
$html_date = 'تاريخ';
$html_sent = 'فرستاده شد';
$html_size = 'سايز';
$html_totalsize = 'سايز کل';
$html_kb = 'کيلو بايت';
$html_bytes = 'بايت';
$html_filename = 'نام فايل';
$html_to = 'به';
$html_cc = 'کپى';
$html_bcc_label = 'کپى محرمانه';
$html_nosubject = 'بدون عنوان';
$html_send = 'بفرست';
$html_cancel = 'کنسل';
$html_no_mail = 'پيغامى وجود ندارد';
$html_logout = 'خروج';
$html_msg = 'پيغام';
$html_msgs = 'پيغامها';
$html_configuration = 'اين سرور درست تنظيم نشده است';
$html_priority_label = 'ارجحيت';
$html_low = 'کم';
$html_normal = 'معمولى';
$html_high = 'زياد';
$html_select = 'انتخاب';
$html_loading_image = 'خواندن تصوير';
$html_send_confirmed = 'نامه شما براى فرستادن پذيرفته شد';
$html_no_sendaction = 'هيچ عملى انجام نشد. JavaScript را فعال نمائيد';
$html_error_occurred = 'يک خطا اتفاق افتاد';
$html_prefs_file_error = 'نمىتوانم فايل تنظيمات فردى را براى نوشتن باز کنم';
$html_smtp_error_no_conn = 'نمىتوانم اتصال SMTP را باز کنم';
$html_smtp_error_unexpected = 'جواب غير قابل انتظار SMTP:';
$lang_could_not_connect = 'نمىتوانم به سرور متصل شوم';

==> nocc-1.8.3.tbz: www/nocc/lang/fa.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fa.php 2199 2010-06-03 23:40:34Z siebrand $
 */

/** Persian (فارسی)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Huji
 */

$lang_locale = 'fa.UTF-8';
$lang_dir = 'rtl';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'شناسه کاربر خالى است';
$err_passwd_empty = 'رمز خالى است';
$alt_delete = 'پاک کردن پيغامهاى انتخاب شده';
$alt_delete_one = 'پاک کردن پيغام';
$alt_new_msg = 'پيغامهاى جديد';
$alt_reply = 'جواب به نويسنده';
$alt_reply_all = 'جواب به همه';
$alt_forward = 'فرستادن پيغام';
$title_next_page = 'پيغام بعدى';
$title_prev_page = 'پيغام قبلى';
$html_welcome = 'خوش آمديد به %1$s';
$html_login = 'شناسه کاربر';
$html_submit = 'ورود';
$html_help = 'راهنما';
$html_wrong = 'شناسه کاربر يا رمز اشتباه است';
$html_retry = 'سعى دوباره';
$html_msgperpage_label = 'تعداد پيغامها در صفحه';
$html_preferences = 'تنظيمات';
$html_full_name_label = 'اسم کامل';
$html_email_address_label = 'آدرس نامه الکترونيکى';
$html_ccself = 'نسخه Cc براى خود';
$html_hide_addresses = 'آدرسها به صورت پنهانى';
$html_outlook_quoting = 'نقل قول شبيه Outlook';
$html_reply_to = 'پاسخ به';
$html_use_signature = 'استفاده از امضا';
$html_signature = 'امضا';
$html_prefs_updated = 'تنطيمات بروز شد';
$html_folders_create_failed = 'شاخه نمىتواند ايجاد شود';
$html_folders_rename_failed = 'شاخه نمىتواند تغيير نام يابد';
$html_folders_updated = 'شاخه ها بروز شدند';
$html_folder_rename = 'تغيير نام';
$html_folder_create = 'ساختن شاخه جديد صدا شد';
$html_folder_to = 'ﺐﻫ';
$html_new_msg_in = 'پيغامهاى جديد در';
$html_or = 'يا';
$html_move = 'تغيير مکان';
$html_copy = 'کپى';
$html_messages_to = 'پيغامهاى انتخاب شده به';
$html_gotopage = 'برو به صفحه';
$html_gotofolder = 'برو به شاخه';
$html_other_folders = 'ليست شاخه ها';
$html_page = 'صفحه';
$html_view_header = 'سرآيند را نشان بده';
$html_remove_header = 'سرآيند را پنهان کن';
$html_new_msg = 'نوشتن نامه';
$html_reply = 'پاسخ دادن';
$html_reply_all = 'پاسخ دادن به همه';
$html_forward = 'فرستادن';
$html_delete = 'پاک کردن';
$html_new = 'جديد';
$html_mark = 'پاک کردن';
$html_att_label = 'ضميمه';
$html_unknown = '[ناشناخته]';
$html_attach = 'ضميمه کن';
$html_attach_forget = 'شما بايد فايل خود را قبل از فرستادن ضميمه کنيد';
$html_attach_delete = 'ضميمه هاى انتخاب شده را پاک کن';
$html_sort_by = 'ترتيب بندى با';
$html_from = 'از';
$html_subject = 'عنوان';
$html_date = 'تاريخ';
$html_sent_label = 'فرستاده شد';
$html_size = 'سايز';
$html_totalsize = 'سايز کل';
$html_kb = 'کيلو بايت';
$html_bytes = 'بايت';
$html_filename = 'نام فايل';
$html_to = 'به';
$html_cc = 'کپى';
$html_bcc_label = 'کپى محرمانه';
$html_nosubject = 'بدون عنوان';
$html_send = 'بفرست';
$html_cancel = 'لغو';
$html_no_mail = 'پيغامى وجود ندارد';
$html_logout = 'خروج';
$html_msg = 'پيغام';
$html_msgs = 'پيغامها';
$html_configuration = 'اين سرور درست تنظيم نشده است';
$html_priority_label = 'ارجحيت';
$html_low = 'کم';
$html_normal = 'معمولى';
$html_high = 'زياد';
$html_select = 'انتخاب';
$html_loading_image = 'خواندن تصوير';
$html_send_confirmed = 'نامه شما براى فرستادن پذيرفته شد';
$html_no_sendaction = 'هيچ عملى انجام نشد. JavaScript را فعال نمائيد';
$html_error_occurred = 'يک خطا اتفاق افتاد';
$html_prefs_file_error = 'نمىتوانم فايل تنظيمات فردى را براى نوشتن باز کنم';
$html_smtp_error_no_conn = 'نمىتوانم اتصال SMTP را باز کنم';
$html_smtp_error_unexpected = 'جواب غير قابل انتظار SMTP:';
$lang_could_not_connect = 'نمىتوانم به سرور متصل شوم';
